@@ -34,7 +34,7 @@ BChoppr::BChoppr (double samplerate, const LV2_Feature* const* features) :
 	map(NULL),
 	rate(samplerate), bpm(120.0f), speed(1), position(0),
 	beatsPerBar (4), beatUnit (4), refFrame(0),
-	prevStep(0), actStep(0), nextStep(1),
+	prevStep(0), actStep(0), nextStep(1), pos (0),
 	audioInput1(NULL), audioInput2(NULL), audioOutput1(NULL), audioOutput2(NULL),
 	sharedDataNr (0),
 	controlPtrs {nullptr}, controllers {0.0f},
@@ -467,22 +467,17 @@ void BChoppr::play(uint32_t start, uint32_t end)
 {
 	int steps = controllers[NrSteps - Controllers];
 
-	//Silence if halted or bpm == 0
-	if ((speed == 0.0f) || (bpm < 1.0f))
-	{
-		memset(&audioOutput1[start], 0, (end-start)*sizeof(float));
-		memset(&audioOutput2[start], 0, (end-start)*sizeof(float));
-		return;
-	}
-
 	for (uint32_t i = start; i < end; ++i)
 	{
 		float effect1 = audioInput1[i];
 		float effect2 = audioInput2[i];
 
 		// Interpolate position within the loop
-		float relpos = (i - refFrame) * speed / (rate / (bpm / 60)) * controllers[SequencesPerBar - Controllers] / beatsPerBar;	// Position relative to reference frame
-		float pos = MODFL (position + relpos);
+		if ((speed != 0.0f) && (bpm >= 1.0f))
+		{
+			float relpos = (i - refFrame) * speed / (rate / (bpm / 60)) * controllers[SequencesPerBar - Controllers] / beatsPerBar;	// Position relative to reference frame
+			pos = MODFL (position + relpos);
+		}
 
 		if (!controllers[Bypass - Controllers])
 		{
@@ -637,7 +632,7 @@ LV2_State_Status BChoppr::state_restore (LV2_State_Retrieve_Function retrieve, L
 	return LV2_STATE_SUCCESS;
 }
 
-LV2_Handle instantiate (const LV2_Descriptor* descriptor, double samplerate, const char* bundle_path, const LV2_Feature* const* features)
+static LV2_Handle instantiate (const LV2_Descriptor* descriptor, double samplerate, const char* bundle_path, const LV2_Feature* const* features)
 {
 	// New instance
 	BChoppr* instance;
@@ -664,16 +659,16 @@ LV2_Handle instantiate (const LV2_Descriptor* descriptor, double samplerate, con
 	return (LV2_Handle)instance;
 }
 
-void connect_port (LV2_Handle instance, uint32_t port, void *data)
+static void connect_port (LV2_Handle instance, uint32_t port, void *data)
 {
 	BChoppr* inst = (BChoppr*) instance;
-	inst->connect_port (port, data);
+	if (inst) inst->connect_port (port, data);
 }
 
-void run (LV2_Handle instance, uint32_t n_samples)
+static void run (LV2_Handle instance, uint32_t n_samples)
 {
 	BChoppr* inst = (BChoppr*) instance;
-	inst->run (n_samples);
+	if (inst) inst->run (n_samples);
 }
 
 static LV2_State_Status state_save(LV2_Handle instance, LV2_State_Store_Function store, LV2_State_Handle handle, uint32_t flags,
@@ -694,10 +689,10 @@ static LV2_State_Status state_restore(LV2_Handle instance, LV2_State_Retrieve_Fu
 	return inst->state_restore (retrieve, handle, flags, features);
 }
 
-void cleanup (LV2_Handle instance)
+static void cleanup (LV2_Handle instance)
 {
 	BChoppr* inst = (BChoppr*) instance;
-	delete inst;
+	if (inst) delete inst;
 }
 
 static const void* extension_data(const char* uri)
@@ -707,7 +702,7 @@ static const void* extension_data(const char* uri)
 	return NULL;
 }
 
-const LV2_Descriptor descriptor =
+static const LV2_Descriptor descriptor =
 {
 		BCHOPPR_URI,
 		instantiate,
